#
# Copyright (c) 2008-2015 Thierry Florac <tflorac AT ulthar.net>
# All Rights Reserved.
#
# This software is subject to the provisions of the Zope Public License,
# Version 2.1 (ZPL).  A copy of the ZPL should accompany this distribution.
# THIS SOFTWARE IS PROVIDED "AS IS" AND ANY AND ALL EXPRESS OR IMPLIED
# WARRANTIES ARE DISCLAIMED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
# WARRANTIES OF TITLE, MERCHANTABILITY, AGAINST INFRINGEMENT, AND FITNESS
# FOR A PARTICULAR PURPOSE.
#

__docformat__ = 'restructuredtext'


# import standard library

# import interfaces
from pyams_form.interfaces.form import IFormLayer
from z3c.form.interfaces import IDataConverter
from zope.schema.interfaces import ITuple

# import packages
from pyams_form.widget import widgettemplate_config
from pyams_utils.adapter import adapter_config
from z3c.form.browser.widget import HTMLFormElement
from z3c.form.converter import BaseDataConverter
from z3c.form.widget import FieldWidget, Widget


@widgettemplate_config(mode='input', template='templates/ordered-list-input.pt', layer=IFormLayer)
@widgettemplate_config(mode='display', template='templates/ordered-list-display.pt', layer=IFormLayer)
class OrderedPluginsWidget(HTMLFormElement, Widget):
    """Ordered plug-ins list widget"""

    def str_value(self):
        return ';'.join(self.value)

    def items(self):
        for name in self.value:
            yield self.context.get_plugin(name)


def OrderedPluginsFieldWidget(field, request):
    return FieldWidget(field, OrderedPluginsWidget(request))


@adapter_config(context=(ITuple, OrderedPluginsWidget), provides=IDataConverter)
class OrderdedPluginsDataConverter(BaseDataConverter):
    """Ordered plugins data converter"""

    def toWidgetValue(self, value):
        return value

    def toFieldValue(self, value):
        return tuple(value.split(';'))
